/*******************************************************
** private.h - To be include by device drive code only.
**
** Author: Tony Denault
** NASA IRTF
** 2680 Woodlawn Drive, Honolulu, HI, 96822
**
*******************************************************/
 
/* The tproinfo is used initialize static information  */
struct tproinfo_t 
{
   char *a16adr;      /* VME bus addres for A16/D16 access */
   char *a32adr;      /* VME bus address for A32/D32 access */
};

/*--------------------------------------------
** structure of all statics the driver needs
*/
struct stuff {
   char *a16adr;      /* VME bus addres for A16/D16 access */
   char *a32adr;      /* VME bus address for A32/D32 access */

	int   iosem;        /* sem to command io */
	int   sem_counter;  /* counter variable for semaphore */
	int   sem_50hz;     /* semaphore to  50 hz signals */
	int   sem_10hz_a;   /* semaphore to  10 hz signals, phase a */
	int   sem_10hz_b;   /* semaphore to  10 hz signals, phase b */
	int   sem_10hz_c;   /* semaphore to  10 hz signals, phase c */
	int   sem_10hz_d;   /* semaphore to  10 hz signals, phase d */
	int   sem_5hz;      /* semaphore to   5 hz signals */

   /* The ISR read the FIFO and puts the info here */
   long yday;           /* days since jan. 1 0-365 */
   long hour;           /* hour     0 - 23   */
   long min;            /* minute   0 - 59   */
   long sec;            /* second   0 - 60   */
   long usec;           /* useconds          */
};
     
/*----------------------------------------------------------------------
**  Common defines for the TPRO-PC, Synchronizable Time Generator board
**----------------------------------------------------------------------
*/
                          /* Virtual address for A32/D32 bus transfers */
#define TPRO_A32 (PHYSBASE+0x02002000)  

                          /* Virtual address for A16/D16 bus transfers */
#define TPRO_A16 (VMESBASE+0x00002000) 

        /* Initialization values for BusInterruptModule on the TPRO */
#define BIMCNT3_DATA  0x001d    /* IntEnb, IntAutoClr, Lvl5 */
#define BIMVEC3_DATA  0x00c8    /* Interrupt vector */

        /* Register offsets for A16 Registers */
#define REG_BIMCNT3      0x06 /* A16/D16 BusInterruptModule Cntl Register 3 */
#define REG_BIMVEC3      0x0e /* A16/D16 BusInterruptModule Vector Register 3 */
#define REG_COMMAND      0x10 /* A16/D16 Command Register */
#define REG_INTER_EVENT  0x12 /* A32/D32 Trigger an event */
#define REG_FIFO_READ    0x14 /* A16/D16 FIFO Data Reads */
#define REG_STATUS       0x18 /* A16/D16 Status Register */

        /* Register offsets for A32 Registers */
#define REG_HWTIME       0x14 /* A32/D32 High order data & freeze release */
#define REG_LWTIME       0x18 /* A32/D32 Time Freeze & low order data */

        /* status register bits */
#define STATUS_FIFO_EMPTY 0x0001 /* "0" FIFO not Empty, "1" FIFO empty */
#define STATUS_CODE_AMP   0x0002 /* "0" <500mV, "1" > 500mV */
#define STATUS_GOOD_SYNC  0x0004 /* "0" Sync error, "1" Good Sync */

/*----------------------------------------------------------------------
**  function prototypes 
**----------------------------------------------------------------------
*/

#if ANSI
int TPRO_csleep( int csec );
int TPRO_csleeph( int *s );
int TPRO_GetStatus( struct stuff *s );
int TPRO_ReadFIFO( struct stuff *s );
int TPRO_GetTime( struct stuff *s, struct tproparms_t * t );
int TPRO_SetTime( struct stuff *s, struct tproparms_t * t );
int TPRO_SyncSem( struct stuff *s );
#else
int TPRO_csleep( );
int TPRO_csleeph( );
int TPRO_GetStatus( );
int TPRO_ReadFIFO( );
int TPRO_GetTime( );
int TPRO_SetTime( );
int TPRO_SyncSem( );
#endif
